@@ -26,15 +26,12 @@ static GdaConnectionPool* connection_pool = NULL;
 static void
 cnc_error_cb (GdaConnectionPool *pool, GdaConnection *cnc, gpointer data)
 {
-	static GtkWidget* error_dialog = NULL;
+	GtkWidget* error_dialog = NULL;
 
 	g_return_if_fail(IS_GDA_CONNECTION_POOL(pool));
 	g_return_if_fail(IS_GDA_CONNECTION(cnc));
 
-	/* FIXME: must not share the same error dialog for all connections */
-	if (!error_dialog) {
-		error_dialog = gnome_db_errordlg_new(cnc, _("Error Viewer"));
-	}
+	error_dialog = gnome_db_errordlg_new(cnc, _("Error Viewer"));
 	gnome_db_errordlg_show_errors(GNOME_DB_ERRORDLG(error_dialog));
 }
 
@@ -70,12 +67,12 @@ components_connection_close (GdaConnection *cnc)
 GdaConnectionPool *
 components_connection_get_pool (void)
 {
-	if (!IS_GDA_CONNECTION_POOL(connection_pool)) {
-		connection_pool = gda_connection_pool_new();
-		gtk_signal_connect(GTK_OBJECT(connection_pool),
-						   "error",
-						   GTK_SIGNAL_FUNC(cnc_error_cb),
-						   NULL);
+	if (!IS_GDA_CONNECTION_POOL (connection_pool)) {
+		connection_pool = gda_connection_pool_new ();
+		gtk_signal_connect (GTK_OBJECT (connection_pool),
+				    "error",
+				    GTK_SIGNAL_FUNC(cnc_error_cb),
+				    NULL);
 	}
 
 	return connection_pool;
