@@ -108,9 +108,12 @@ static GnomeUIInfo databasemenu[] = {
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo toolsmenu[] = {
-	{ GNOME_APP_UI_ITEM, N_("Export database"), N_("Export a database to a file or to another database"),
+	{ GNOME_APP_UI_ITEM, N_("Export database"), N_("Make a copy of a database"),
 	  export_database_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
 	  GNOME_STOCK_MENU_FORWARD, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, N_("Import database"), N_("Import an export file into a database"),
+	  NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GNOME_STOCK_MENU_BACK, 0, 0, NULL },
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo helpmenu[] = {
@@ -167,7 +170,9 @@ fill_saved_query_list (GtkCList *clist)
 			gchar* tmp;
 
 			row[0] = (gchar *) node->data;
-			tmp = g_strdup_printf("%s/%s", GNOME_DB_CONFIG_SECTION_SAVED_SQL_QUERIES, (gchar *) node->data);
+			tmp = g_strdup_printf("%s/%s",
+					      GNOME_DB_CONFIG_SECTION_SAVED_SQL_QUERIES,
+					      (gchar *) node->data);
 			row[1] = gda_config_get_string(tmp);
 			g_free((gpointer) tmp);
 			gtk_clist_append(clist, row);
@@ -263,12 +268,12 @@ init_browser_window (connection_instance_data_t *instance_data)
 	
 	instance_data->browser_tab = gnome_db_browser_new(instance_data->cnc);
 	gnome_db_set_widget_tooltip(instance_data->browser_tab,
-								_("This screen lets you navigate through the contents "
-								  "of your database, looking at the tables, views, "
-								  "procedures, etc that may have created. Clicking "
-								  "on an icon in one of the lists on the left, will "
-								  "display extensive information about that selected "
-								  "object in the right-hand pane"));
+				    _("This screen lets you navigate through the contents "
+				      "of your database, looking at the tables, views, "
+				      "procedures, etc that may have created. Clicking "
+				      "on an icon in one of the lists on the left, will "
+				      "display extensive information about that selected "
+				      "object in the right-hand pane"));
 	gtk_widget_show(instance_data->browser_tab);
 	gtk_notebook_append_page(GTK_NOTEBOOK(instance_data->tab),
 	                         instance_data->browser_tab,
@@ -531,24 +536,20 @@ do_print_cb (GnomeDbControl *control, connection_control_data_t *control_data)
 static void
 export_database_cb (GtkWidget *w, GnomeDbControl *control)
 {
+	GtkWidget *dialog;
 	GtkWidget *export;
 
-	/* load the control */
-	export = components_export_create_widget();
-	if (GTK_IS_WIDGET(export)) {
-		GtkWidget *dialog;
+	/* create the dialog box */
+	dialog = gnome_dialog_new (_("Export database"),
+				   GNOME_STOCK_BUTTON_CLOSE,
+				   NULL);
 
-		/* create the dialog */
-		dialog = gnome_dialog_new(_("Export Database"),
-								  GNOME_STOCK_BUTTON_CLOSE,
-								  NULL);
-		gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), export, 1, 1, 0);
+	export = gnome_db_export_new ();
+	gtk_widget_show (export);
+	gnome_db_export_set_pool (export, components_connection_get_pool ());
+	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), export, TRUE, TRUE, 0);
 
-		/* run the dialog */
-		gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
-	}
-	else
-		gnome_db_show_error(_("Could not activate export component"));
+	gtk_widget_show (dialog);
 }
 
 static void
