@@ -23,7 +23,7 @@
 #include "gnome-db-list.h"
 #include "gnome-db-util.h"
 #include <libgnome/gnome-i18n.h>
-#include <gal/e-paned/e-hpaned.h>
+#include "e-hpaned.h"
 
 struct _GnomeDbBrowserPrivate {
 	GdaConnection* cnc;
@@ -45,9 +45,9 @@ static void refresh_list_cb (GtkWidget *w, gpointer user_data);
 static void show_extra_info_cb (GtkWidget *w, gpointer user_data);
 static void show_table_data_cb (GtkWidget *w, gpointer user_data);
 static void switch_notebook_page_cb (GtkNotebook *notebook,
-									 GtkNotebookPage *page,
-									 guint page_num,
-									 gpointer user_data);
+				     GtkNotebookPage *page,
+				     guint page_num,
+				     gpointer user_data);
 
 enum {
 	CONNECTION_CHANGED,
@@ -107,19 +107,19 @@ create_table_detail (GnomeDbBrowser *browser, const gchar *name)
 	GtkWidget *grid;
 	GdaRecordset *recset;
 
-	g_return_val_if_fail(GNOME_DB_IS_BROWSER(browser), NULL);
+	g_return_val_if_fail (GNOME_DB_IS_BROWSER (browser), NULL);
 
 	grid = gnome_db_grid_new(NULL);
 	gtk_widget_show(grid);
 
-	if (gda_connection_is_open(browser->priv->cnc)) {
+	if (gda_connection_is_open (browser->priv->cnc)) {
 		/* get list of columns from database */
-		recset = gda_connection_open_schema(browser->priv->cnc,
-											GDA_Connection_GDCN_SCHEMA_COLS,
-											GDA_Connection_OBJECT_NAME,
-											name,
-											GDA_Connection_no_CONSTRAINT);
-		gnome_db_grid_set_recordset(GNOME_DB_GRID(grid), recset);
+		recset = gda_connection_open_schema (browser->priv->cnc,
+						     GDA_Connection_GDCN_SCHEMA_COLS,
+						     GDA_Connection_OBJECT_NAME,
+						     name,
+						     GDA_Connection_no_CONSTRAINT);
+		gnome_db_grid_set_recordset (GNOME_DB_GRID (grid), recset);
 	}
 
 	return grid;
@@ -256,17 +256,17 @@ show_extra_info_cb (GtkWidget *w, gpointer user_data)
 		object_name = gnome_db_list_get_string(list);
 		if (object_name) {
 			recset = gda_connection_open_schema(browser->priv->cnc,
-												object_managers[page_num].qtype,
-												GDA_Connection_EXTRA_INFO,
-												"",
-												GDA_Connection_OBJECT_NAME,
-												object_name,
-												GDA_Connection_no_CONSTRAINT);
+							    object_managers[page_num].qtype,
+							    GDA_Connection_EXTRA_INFO,
+							    "",
+							    GDA_Connection_OBJECT_NAME,
+							    object_name,
+							    GDA_Connection_no_CONSTRAINT);
 			if (recset) {
 				/* build the dialog */
 				dialog = gnome_dialog_new(_("Extra information"),
-										  GNOME_STOCK_BUTTON_CLOSE,
-										  NULL);
+							  GNOME_STOCK_BUTTON_CLOSE,
+							  NULL);
 				table = gnome_db_new_table_widget(3, 2, FALSE);
 				gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), table, 1, 1, 0);
 
@@ -275,16 +275,16 @@ show_extra_info_cb (GtkWidget *w, gpointer user_data)
 					pixmap_widget = GTK_WIDGET(gnome_pixmap_new_from_gnome_pixmap(pixmap));
 					gtk_widget_show(pixmap_widget);
 					gtk_table_attach(GTK_TABLE(table), pixmap_widget, 0, 1, 0, 1,
-									 GTK_FILL, GTK_FILL, 3, 3);
+							 GTK_FILL, GTK_FILL, 3, 3);
 				}
 
 				grid = gnome_db_dataset_new(recset);
 				gnome_db_dataset_set_show_buttons(GNOME_DB_DATASET(grid), FALSE);
 				gtk_widget_show(grid);
 				gtk_table_attach(GTK_TABLE(table), grid, 0, 2, 1, 3,
-								 GTK_FILL | GTK_SHRINK | GTK_EXPAND,
-								 GTK_FILL | GTK_SHRINK | GTK_EXPAND,
-								 3, 3);
+						 GTK_FILL | GTK_SHRINK | GTK_EXPAND,
+						 GTK_FILL | GTK_SHRINK | GTK_EXPAND,
+						 3, 3);
 
 				/* run the dialog */
 				gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
@@ -305,7 +305,7 @@ show_table_data_cb (GtkWidget *w, gpointer user_data)
 
 	page_num = gtk_notebook_get_current_page(GTK_NOTEBOOK(browser->priv->object_selector));
 	list = (GnomeDbList *) gtk_notebook_get_nth_page(GTK_NOTEBOOK(browser->priv->object_selector),
-													 page_num);
+							 page_num);
 	if (GNOME_DB_IS_LIST(list) && IS_GDA_CONNECTION(browser->priv->cnc)) {
 		gchar *object_name;
 
@@ -347,9 +347,9 @@ show_table_data_cb (GtkWidget *w, gpointer user_data)
 
 static void
 switch_notebook_page_cb (GtkNotebook *notebook,
-						 GtkNotebookPage *page,
-						 guint page_num,
-						 gpointer user_data)
+			 GtkNotebookPage *page,
+			 guint page_num,
+			 gpointer user_data)
 {
 	GnomeDbList *list;
 	GnomeDbBrowser *browser = (GnomeDbBrowser *) user_data;
@@ -388,11 +388,11 @@ gnome_db_browser_class_init (GnomeDbBrowserClass *klass)
 
 	db_browser_signals[CONNECTION_CHANGED] =
 		gtk_signal_new("connection_changed",
-					   GTK_RUN_LAST,
-					   object_class->type,
-					   GTK_SIGNAL_OFFSET(GnomeDbBrowserClass, connection_changed),
-					   gtk_signal_default_marshaller,
-					   GTK_TYPE_NONE, 0);
+			       GTK_RUN_LAST,
+			       object_class->type,
+			       GTK_SIGNAL_OFFSET(GnomeDbBrowserClass, connection_changed),
+			       gtk_signal_default_marshaller,
+			       GTK_TYPE_NONE, 0);
 	gtk_object_class_add_signals(object_class, db_browser_signals, LAST_SIGNAL);
 
 	object_class->destroy = gnome_db_browser_destroy;
