@@ -41,12 +41,28 @@ impl_GNOME_DB_Control_run (PortableServer_Servant servant,
 {
 }
 
+void
+impl_GNOME_DB_Control_setOwner (PortableServer_Servant servant,
+				CORBA_Environment *ev)
+{
+	g_return_if_fail (servant != NULL);
+	gtk_signal_emit_by_name (GTK_OBJECT (bonobo_x_object (servant)), "set_owner");
+}
+
+void
+impl_GNOME_DB_Control_unsetOwner (PortableServer_Servant servant,
+				  CORBA_Environment *ev)
+{
+	g_return_if_fail (servant != NULL);
+	gtk_signal_emit_by_name (GTK_OBJECT (bonobo_x_object (servant)), "unset_owner");
+}
+
 void
 impl_GNOME_DB_Control_doPrint (PortableServer_Servant servant,
                                CORBA_Environment *ev)
 {
-	g_return_if_fail(servant != NULL);
-	gtk_signal_emit_by_name(GTK_OBJECT(bonobo_x_object (servant)), "do_print");
+	g_return_if_fail (servant != NULL);
+	gtk_signal_emit_by_name (GTK_OBJECT (bonobo_x_object (servant)), "do_print");
 }
 
 void
