@@ -34,6 +34,11 @@ CORBA_char* impl_GNOME_DB_Control_getAuthors (PortableServer_Servant servant,
 void impl_GNOME_DB_Control_run (PortableServer_Servant servant,
                                 CORBA_Environment *ev);
 
+void impl_GNOME_DB_Control_setOwner (PortableServer_Servant servant,
+				     CORBA_Environment *ev);
+void impl_GNOME_DB_Control_unsetOwner (PortableServer_Servant servant,
+				       CORBA_Environment *ev);
+
 void impl_GNOME_DB_Control_doPrint (PortableServer_Servant servant,
                                     CORBA_Environment *ev);
 void impl_GNOME_DB_Control_doCutClipboard (PortableServer_Servant servant,
