@@ -37,6 +37,8 @@ struct _GnomeDbControlPrivate {
 enum {
 	GET_PROPERTY,
 	SET_PROPERTY,
+	SET_OWNER,
+	UNSET_OWNER,
 	DO_PRINT,
 	DO_CUT_CLIPBOARD,
 	DO_COPY_CLIPBOARD,
@@ -54,39 +56,55 @@ control_activated_cb (BonoboControl *bonobo_control,
                       gboolean activate,
                       GnomeDbControl *control)
 {
-	if (activate) gnome_db_control_activate(control);
-	else gnome_db_control_deactivate(control);
-}
-
-static void
-control_destroyed_cb (GnomeDbControl *control, gpointer data)
-{
-	CORBA_Environment ev;
-	
-	g_return_if_fail(GNOME_DB_IS_CONTROL(control));
-	g_free((gpointer) control->priv);
+	if (activate)
+		gnome_db_control_activate(control);
+	else
+		gnome_db_control_deactivate(control);
 }
 
 static void
 get_prop_cb (BonoboPropertyBag *bag, BonoboArg *arg, guint arg_id, gpointer user_data)
 {
+	GnomeDbControl *control = (GnomeDbControl *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_CONTROL (control));
 }
 
 static void
 set_prop_cb (BonoboPropertyBag *bag, const BonoboArg *arg, guint arg_id, gpointer user_data)
 {
+	GnomeDbControl *control = (GnomeDbControl *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_CONTROL (control));
 }
 
 static void
 widget_destroyed_cb (GtkWidget *w, GnomeDbControl *control)
 {
 	g_return_if_fail(GNOME_DB_IS_CONTROL(control));
-	gtk_object_unref(GTK_OBJECT(control));
+	bonobo_object_unref(BONOBO_OBJECT(control));
 }
 
 /*
  * GnomeDbControl object
  */
+static void
+gnome_db_control_destroy (GtkObject *object)
+{
+	GtkObjectClass *parent_class;
+	GnomeDbControl *control = (GnomeDbControl *) object;
+
+	g_return_if_fail(GNOME_DB_IS_CONTROL(control));
+
+	bonobo_object_unref(BONOBO_OBJECT(control->priv->bonobo_control));
+	bonobo_object_unref(BONOBO_OBJECT(control->priv->ui_component));
+	g_free((gpointer) control->priv);
+
+	parent_class = gtk_type_class(PARENT_TYPE);
+	if (parent_class && parent_class->destroy)
+		parent_class->destroy(object);
+}
+
 static void
 gnome_db_control_class_init (GnomeDbControlClass *klass)
 {
@@ -108,6 +126,20 @@ gnome_db_control_class_init (GnomeDbControlClass *klass)
 		               gtk_marshal_NONE__POINTER_POINTER_POINTER,
 		               GTK_TYPE_NONE, 3, GTK_TYPE_POINTER, GTK_TYPE_STRING,
 		               GTK_TYPE_POINTER);
+	control_signals[SET_OWNER] =
+		gtk_signal_new("set_owner",
+			       GTK_RUN_FIRST,
+			       object_class->type,
+			       GTK_SIGNAL_OFFSET (GnomeDbControlClass, set_owner),
+			       gtk_signal_default_marshaller,
+			       GTK_TYPE_NONE, 0);
+	control_signals[UNSET_OWNER] =
+		gtk_signal_new("unset_owner",
+			       GTK_RUN_FIRST,
+			       object_class->type,
+			       GTK_SIGNAL_OFFSET (GnomeDbControlClass, unset_owner),
+			       gtk_signal_default_marshaller,
+			       GTK_TYPE_NONE, 0);
 	control_signals[DO_PRINT] =
 		gtk_signal_new("do_print",
 		               GTK_RUN_FIRST,
@@ -138,7 +170,8 @@ gnome_db_control_class_init (GnomeDbControlClass *klass)
 		               GTK_TYPE_NONE, 0);
 
 	gtk_object_class_add_signals(object_class, control_signals, LAST_SIGNAL);
-	
+
+	object_class->destroy = gnome_db_control_destroy;
 	klass->get_property = NULL;
 	klass->set_property = NULL;
 	klass->do_print = NULL;
@@ -146,6 +179,8 @@ gnome_db_control_class_init (GnomeDbControlClass *klass)
 	klass->do_copy_clipboard = NULL;
 	klass->do_paste_clipboard = NULL;
 
+	epv->setOwner = impl_GNOME_DB_Control_setOwner;
+	epv->unsetOwner = impl_GNOME_DB_Control_unsetOwner;
 	epv->getVersion = impl_GNOME_DB_Control_getVersion;
 	epv->getAuthors = impl_GNOME_DB_Control_getAuthors;
 	epv->run = impl_GNOME_DB_Control_run;
@@ -206,11 +241,6 @@ gnome_db_control_construct (GnomeDbControl *control, GtkWidget *w)
 	
 	g_return_val_if_fail(GNOME_DB_IS_CONTROL(control), NULL);
 	g_return_val_if_fail(GTK_IS_WIDGET(w), NULL);
-	
-	gtk_signal_connect(GTK_OBJECT(control),
-	                   "destroy",
-	                   GTK_SIGNAL_FUNC(control_destroyed_cb),
-	                   NULL);
 
 	control->priv->widget = w;
 	gtk_signal_connect(GTK_OBJECT(control->priv->widget),
@@ -227,9 +257,10 @@ gnome_db_control_construct (GnomeDbControl *control, GtkWidget *w)
 	                            BONOBO_OBJECT(control->priv->bonobo_control));
 
 	/* create property bag */
-	control->priv->properties = bonobo_property_bag_new((BonoboPropertyGetFn) get_prop_cb,
-	                                                          (BonoboPropertySetFn) set_prop_cb,
-	                                                          (gpointer) control);
+	control->priv->properties = bonobo_property_bag_new(
+		(BonoboPropertyGetFn) get_prop_cb,
+		(BonoboPropertySetFn) set_prop_cb,
+		(gpointer) control);
 	bonobo_control_set_properties(control->priv->bonobo_control,
 	                              control->priv->properties);
 
@@ -239,7 +270,9 @@ gnome_db_control_construct (GnomeDbControl *control, GtkWidget *w)
 	                                control->priv->ui_component);
 	control->priv->ui_handler = bonobo_ui_handler_new_from_component(control->priv->ui_component);
 
-	return control;
+	return bonobo_object_construct(
+		BONOBO_OBJECT(control),
+		bonobo_object_corba_objref (BONOBO_OBJECT (control)));
 }
 
 /**
@@ -253,7 +286,6 @@ gnome_db_control_new (GtkWidget *w)
 	g_return_val_if_fail(GTK_IS_WIDGET(w), NULL);
 	
 	control = GNOME_DB_CONTROL(gtk_type_new(gnome_db_control_get_type()));
-
 	return gnome_db_control_construct(control, w);
 }
 
@@ -334,8 +366,10 @@ gnome_db_control_deactivate (GnomeDbControl *control)
 	g_return_if_fail(GNOME_DB_IS_CONTROL(control));
 	
 	uic = bonobo_control_get_ui_component(control->priv->bonobo_control);
-	if (uic)
+	if (uic) {
+		bonobo_ui_component_rm(uic, "/", NULL);
 		bonobo_ui_component_unset_container(uic);
+	}
 }
 
 /**
@@ -349,7 +383,8 @@ gnome_db_control_set_status (GnomeDbControl *control, const gchar *msg)
 	g_return_if_fail(GNOME_DB_CONTROL(control));
 	
 	uic = bonobo_control_get_ui_component(control->priv->bonobo_control);
-	if (uic) bonobo_ui_component_set_status(uic, msg, NULL);
+	if (uic)
+		bonobo_ui_component_set_status(uic, msg, NULL);
 }
 
 /**
