@@ -39,21 +39,22 @@ typedef struct _GnomeDbControlClass GnomeDbControlClass;
 
 typedef struct _GnomeDbControlPrivate GnomeDbControlPrivate;
 
-struct _GnomeDbControl
-{
+struct _GnomeDbControl {
 	BonoboXObject           bonobo_object;
 	GnomeDbControlPrivate* priv;
 };
 
-struct _GnomeDbControlClass
-{
+struct _GnomeDbControlClass {
 	BonoboXObjectClass parent_class; 
 
 	POA_GNOME_DB_Control__epv epv;
   
 	void              (*get_property)(GnomeDbControl *control, const gchar *name);
 	void              (*set_property)(GnomeDbControl *control, const gchar *name);
-  
+
+	void              (*set_owner)(GnomeDbControl *control);
+	void              (*unset_owner)(GnomeDbControl *control);
+
 	void              (*do_print)(GnomeDbControl *control);
 	void              (*do_cut_clipboard)(GnomeDbControl *control);
 	void              (*do_copy_clipboard)(GnomeDbControl *control);
