@@ -19,7 +19,8 @@
 #ifndef __gnome_db_grid_h__
 #define __gnome_db_grid_h__ 1
 
-#include <gnome.h>
+#include <gtk/gtkvbox.h>
+#include <libgnome/gnome-defs.h>
 #include <gda-recordset.h>
 
 BEGIN_GNOME_DECLS
@@ -33,32 +34,29 @@ BEGIN_GNOME_DECLS
 typedef struct _GnomeDbGrid      GnomeDbGrid;
 typedef struct _GnomeDbGridClass GnomeDbGridClass;
 
-struct _GnomeDbGrid
-{
-  GtkVBox        parent;
-  GtkWidget*     scrolled_window;
-  GtkWidget*     grid; 
-  Gda_Recordset* recset; 
-  gint           total_rows;
-  gboolean       show_row_numbers;
-  gboolean       show_col_names;
-  gint           timeout_handle;
+struct _GnomeDbGrid {
+	GtkVBox        parent;
+	GtkWidget*     scrolled_window;
+	GtkWidget*     grid; 
+	GdaRecordset* recset; 
+	gint           total_rows;
+	gboolean       show_row_numbers;
+	gboolean       show_col_names;
+	gint           timeout_handle;
 };
 
-struct _GnomeDbGridClass
-{
-  GtkVBoxClass parent_class;
-
-  void         (*error)       (GnomeDbGrid *grid);
-  void         (*loaded)      (GnomeDbGrid *grid);
-  void         (*select_row)  (GnomeDbGrid *grid, gint row);
-  void         (*unselect_row)(GnomeDbGrid *grid, gint row);
-  void         (*add_row)     (GnomeDbGrid *grid, gint row);
+struct _GnomeDbGridClass {
+	GtkVBoxClass parent_class;
+	
+	void         (*error)       (GnomeDbGrid *grid);
+	void         (*loaded)      (GnomeDbGrid *grid);
+	void         (*select_row)  (GnomeDbGrid *grid, gint row);
+	void         (*unselect_row)(GnomeDbGrid *grid, gint row);
+	void         (*add_row)     (GnomeDbGrid *grid, gint row);
 };
 
 guint          gnome_db_grid_get_type              (void);
-GtkWidget*     gnome_db_grid_new                   (Gda_Recordset *recset);
-void           gnome_db_grid_destroy               (GnomeDbGrid *grid);
+GtkWidget*     gnome_db_grid_new                   (GdaRecordset *recset);
 
 void           gnome_db_grid_set_background        (GnomeDbGrid *grid,
                                                     gint row,
@@ -89,9 +87,9 @@ void           gnome_db_grid_show_row_numbers      (GnomeDbGrid *grid);
 #define        gnome_db_grid_get_row_count(grid)   (GNOME_DB_GRID(grid)->total_rows)
 void           gnome_db_grid_clear                 (GnomeDbGrid *grid);
 void           gnome_db_grid_refresh               (GnomeDbGrid *grid);
-Gda_Recordset* gnome_db_grid_get_recordset         (GnomeDbGrid *grid);
+GdaRecordset* gnome_db_grid_get_recordset         (GnomeDbGrid *grid);
 void           gnome_db_grid_set_recordset         (GnomeDbGrid *grid,
-                                                    Gda_Recordset *recset);
+                                                    GdaRecordset *recset);
 
 END_GNOME_DECLS
 
