@@ -20,6 +20,9 @@
 #if !defined(__gnome_db_shortcut_h__)
 #  define __gnome_db_shortcut_h__
 
+#include <gtk/gtkvbox.h>
+#include <libgnome/gnome-defs.h>
+
 BEGIN_GNOME_DECLS
 
 typedef struct _GnomeDbShortcut      GnomeDbShortcut;
@@ -44,7 +47,8 @@ struct _GnomeDbShortcutClass
   GtkVBoxClass parent_class;
 };
 
-GtkWidget* gnome_db_shortcut_new    (void);
+GtkType    gnome_db_shortcut_get_type (void);
+GtkWidget* gnome_db_shortcut_new (void);
 void       gnome_db_shortcut_append (GnomeDbShortcut *shortcut,
                                      const gchar *str,
                                      const gchar *tooltip,
