@@ -20,7 +20,9 @@
 #if !defined(__gnome_db_window_h__)
 #  define __gnome_db_window_h__
 
-#include <gnome.h>
+#include <libgnome/gnome-defs.h>
+#include <libgnomeui/libgnomeui.h>
+#include <bonobo/bonobo-win.h>
 
 BEGIN_GNOME_DECLS
 
@@ -35,17 +37,15 @@ typedef struct _GnomeDbWindowClass GnomeDbWindowClass;
 
 typedef struct _GnomeDbWindowPrivate GnomeDbWindowPrivate;
 
-struct _GnomeDbWindow
-{
-  BonoboWindow          window;
-  GnomeDbWindowPrivate* priv;
+struct _GnomeDbWindow {
+	BonoboWindow          window;
+	GnomeDbWindowPrivate* priv;
 };
 
-struct _GnomeDbWindowClass
-{
-  BonoboWindowClass parent_class;
+struct _GnomeDbWindowClass {
+	BonoboWindowClass parent_class;
   
-  void              (*close)(GnomeDbWindow *window);
+	void              (*close)(GnomeDbWindow *window);
 };
 
 GtkType            gnome_db_window_get_type         (void);
