@@ -21,7 +21,7 @@
 static guint prepare_app (void);
 
 GtkWidget*      glb_mainwin = NULL;
-Gda_Connection* glb_connection = NULL;
+GdaConnection* glb_connection = NULL;
 
 int
 main (int argc, char *argv[])
